# society 🎭

a tool to simulate group interactions

- study emergent behaviors
- basic agency loops for agents

- simulate ideas

- can the whole be greater than the parts?
- what is the IQ of a city?
- can we simulate humans as fluids instead of molecules?
- team management is all about incentives
- are we in a simulation?
- jaggedness of LLMs can be reduced

- deep research angle

- hold a summit of your heroes
- market test

CLI and web app

website link, local or CLI

## Getting Started
TODO
```
pip install society
society dev
```

api key. set env or in UI

### CLI

example here

### Development

```bash
curl -LsSf https://astral.sh/uv/install.sh | sh
uv venv --python=3.12 .venv
source .venv/bin/activate
git clone https://github.com/hmartiros/society.git
uv pip install -r requirements.txt
society
```

```
society dev
```
